====================
Conversion functions
====================

.. warning::
   These conversion functions are for testing only and it's expected that
   this functionality will eventually be integrated into the relevant
   third-party library.

.. autofunction:: demes.convert.to_msprime
.. autofunction:: demes.convert.from_msprime
.. autofunction:: demes.convert.to_stdpopsim
.. autofunction:: demes.convert.from_stdpopsim
